===================
ESM Class
===================

The ESM Class provides the interface to interact with the ESM management
functions and status visibility.

Like the SIEM itself, the ESM object is the gateway to everything else:

